@@ -71,17 +71,20 @@ static R_CallMethodDef CallEntries[] = {
     {"PROJ4VersionInfo", (DL_FUNC) &PROJ4VersionInfo, 0},
     {"PROJ4NADsInstalled", (DL_FUNC) &PROJ4NADsInstalled, 0},
     {"get_proj_search_path", (DL_FUNC) &get_proj_search_path, 0},
-    {"set_proj_search_path", (DL_FUNC) &set_proj_search_path, 1},
+    {"get_proj_user_writable_dir", (DL_FUNC) &get_proj_user_writable_dir, 0},
+    {"set_proj_paths", (DL_FUNC) &set_proj_paths, 1},
     {"PROJ4_proj_def_dat_Installed", (DL_FUNC) &PROJ4_proj_def_dat_Installed, 0},
     {"transform", (DL_FUNC) &transform, 6},
-    {"transform_ng", (DL_FUNC) &transform_ng, 7},
+    {"transform_ng", (DL_FUNC) &transform_ng, 8},
     {"RGDAL_projInfo", (DL_FUNC) &RGDAL_projInfo, 1},
     {"RGDAL_project", (DL_FUNC) &RGDAL_project, 5},
     {"project_inv", (DL_FUNC) &project_inv, 5},
     {"project_ng", (DL_FUNC) &project_ng, 7},
-    {"project_ng_coordOp", (DL_FUNC) &project_ng_coordOp, 2},
+    {"project_ng_coordOp", (DL_FUNC) &project_ng_coordOp, 3},
     {"CRS_compare", (DL_FUNC) &CRS_compare, 4},
     {"proj_network_enabled", (DL_FUNC) &proj_network_enabled, 0},
+    {"enable_proj_network", (DL_FUNC) &enable_proj_network, 0},
+    {"disable_proj_network", (DL_FUNC) &disable_proj_network, 0},
     {"RGDAL_SetGeoTransform", (DL_FUNC) &RGDAL_SetGeoTransform, 2},
     {"RGDAL_GetNoDataValue", (DL_FUNC) &RGDAL_GetNoDataValue, 1},
     {"RGDAL_GetMetadata", (DL_FUNC) &RGDAL_GetMetadata, 2},
